@@ -25,7 +25,7 @@ def train(params, train_set, num_boost_round=100,
           early_stopping_rounds=None, evals_result=None,
           verbose_eval=True, learning_rates=None,
           keep_training_booster=False, callbacks=None):
-    """Perform the training with given parameters.
+    """Training function.
 
     Parameters
     ----------
@@ -521,7 +521,7 @@ def cv(params, train_set, num_boost_round=100,
        verbose_eval=None, show_stdv=False, seed=0,
        callbacks=None, eval_train_metric=False,
        return_cvbooster=False):
-    """Perform the cross-validation with given paramaters.
+    """Perform cross-validation for choosing number of boosting iterations.
 
     Parameters
     ----------
@@ -992,11 +992,13 @@ def grid_search_tune_parameters(param_grid, train_set, params=None, num_try_rand
         if num_try_random > grid_size:
             raise ValueError("num_try_random is larger than the number of all possible combinations of parameters in param_grid")
         try_param_combs = np.random.RandomState(seed).choice(a=grid_size, size=num_try_random, replace=False)
-        print("Starting random grid search with " + str(num_try_random) + " trials out of " + str(
-            grid_size) + " parameter combinations...")
+        if verbose_eval >= 1:
+            print("Starting random grid search with " + str(num_try_random) + " trials out of " + str(
+                grid_size) + " parameter combinations...")
     else:
         try_param_combs = range(grid_size)
-        print("Starting deterministic grid search with " + str(grid_size) + " parameter combinations...")
+        if verbose_eval >= 1:
+            print("Starting deterministic grid search with " + str(grid_size) + " parameter combinations...")
     if verbose_eval < 2:
         verbose_eval_cv = False
     else:
